/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.cloudfarming.eventbus;

/**
 * Interface for GuiEventListeners.<p/>
 * 
 * Implementations can be registered in META-INF/services/nl.cloudfarming.eventbus.GuiEventListener
 * 
 * @author Timon Veenstra
 */
public interface GuiEventListener<C> {
    /**
     * Event must be handled here. If the listener is listening to multiple event keys
     * events handled here could be from different event keys.
     * 
     * @param event
     */
    void onEvent(GuiEvent<C> event);
    /**
     * used to determine if an event should be send to a listener.
     * Only events with keys a listener is listening to will be broadcasted to 
     * the listener.<p/>
     * return true; will result in a Listener listening to all possible events.
     * 
     * 
     * @param guiEventKey
     * @return
     */
    boolean listensTo(GuiEventKey guiEventKey);
    
    /**
     * Return name of the module the listener is in.
     * Needed to determine if the module is enabled or not.
     * 
     * module name can be retrieved from the bundle.properties.
     * example implementation:
     * 
     *     public String getModuleName() {
     *        return NbBundle.getMessage(this.getClass(), "OpenIDE-Module-Name");
     *     }
     * 
     * @return name of the module the EventListener
     */
    String getModuleName();
}
